<!--
https://pypi.org/project/readme-generator/
-->

[![](https://img.shields.io/badge/language-Python-blue.svg?longCache=True)]()

#### Installation
```bash
$ [sudo] pip install django-manage
```

#### Examples
```bash
$ export DJANGO_SETTINGS_MODULE="<settings>"
$ manage.py <command>
```

<p align="center">
    <a href="https://pypi.org/project/readme-generator/">readme-generator</a>
</p>